'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var react = require('react');
var react__default = _interopDefault(react);
var clsx = _interopDefault(require('clsx'));
var effectorReact = require('effector-react');
var atomicRouter = require('atomic-router');
var jsxRuntime = require('react/jsx-runtime');

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var RouterContext = /*#__PURE__*/react.createContext(null);
function RouterProvider(_ref) {
  var router = _ref.router,
      children = _ref.children;
  return /*#__PURE__*/jsxRuntime.jsx(RouterContext.Provider, {
    value: router,
    children: children
  });
}
function useRouter() {
  return react.useContext(RouterContext);
}

var _excluded = ["to", "params", "query", "className", "activeClassName", "inactiveClassName"],
    _excluded2 = ["className"],
    _excluded3 = ["to", "params", "query", "className", "activeClassName", "inactiveClassName", "onClick"];
function Link(_ref) {
  var to = _ref.to,
      params = _ref.params,
      query = _ref.query,
      className = _ref.className,
      _ref$activeClassName = _ref.activeClassName,
      activeClassName = _ref$activeClassName === void 0 ? 'active' : _ref$activeClassName,
      inactiveClassName = _ref.inactiveClassName,
      props = _objectWithoutPropertiesLoose(_ref, _excluded);

  if (typeof to === 'string') {
    return /*#__PURE__*/jsxRuntime.jsx(NormalLink, _extends({
      href: to,
      className: className
    }, props));
  }

  return /*#__PURE__*/jsxRuntime.jsx(RouteLink, _extends({
    to: to,
    params: params,
    query: query,
    className: className,
    activeClassName: activeClassName,
    inactiveClassName: inactiveClassName
  }, props));
}

function NormalLink(_ref2) {
  var className = _ref2.className,
      props = _objectWithoutPropertiesLoose(_ref2, _excluded2);

  return /*#__PURE__*/jsxRuntime.jsx("a", _extends({
    className: clsx(className)
  }, props));
}

function RouteLink(_ref3) {
  var to = _ref3.to,
      params = _ref3.params,
      query = _ref3.query,
      className = _ref3.className,
      _ref3$activeClassName = _ref3.activeClassName,
      activeClassName = _ref3$activeClassName === void 0 ? 'active' : _ref3$activeClassName,
      inactiveClassName = _ref3.inactiveClassName,
      _onClick = _ref3.onClick,
      props = _objectWithoutPropertiesLoose(_ref3, _excluded3);

  var router = useRouter();
  var routeObj = router.routes.find(function (routeObj) {
    return routeObj.route === to;
  });

  if (!routeObj) {
    throw new Error('[RouteLink] Route not found');
  }

  var isOpened = effectorReact.useStore(routeObj.route.$isOpened);
  var href = atomicRouter.buildPath({
    pathCreator: routeObj.path,
    params: params || {},
    query: query || {}
  });
  return /*#__PURE__*/jsxRuntime.jsx("a", _extends({
    href: href,
    className: clsx(className, isOpened ? activeClassName : inactiveClassName),
    onClick: function onClick(evt) {
      evt.preventDefault();
      to.navigate({
        params: params || {},
        query: query || {}
      });

      if (_onClick) {
        _onClick(evt);
      }
    }
  }, props, {
    children: props.children
  }));
}

function Route(_ref) {
  var route = _ref.route,
      Component = _ref.view;
  var router = useRouter();
  /* eslint-disable */

  var isOpened = effectorReact.useStoreMap({
    store: router.$activeRoutes,
    keys: [route],
    fn: function fn(activeRoutes, _ref2) {
      var route = _ref2[0];
      return Array.isArray(route) ? route.some(function (route) {
        return activeRoutes.includes(route);
      }) : activeRoutes.includes(route);
    }
  });

  if (isOpened) {
    return /*#__PURE__*/jsxRuntime.jsx(Component, {});
  }

  return null;
}

exports.Link = Link;
exports.Route = Route;
exports.RouterContext = RouterContext;
exports.RouterProvider = RouterProvider;
exports.useRouter = useRouter;
//# sourceMappingURL=atomic-router-react.cjs.development.js.map
